@@ -38,9 +38,9 @@
   else {
     phi.scale <- mcmc.input$phi.scale
     if(nmphi > 1 && pnorm((phi.discrete[nmphi] - phi.discrete[1])/(nmphi - 1), sd = sqrt(phi.scale)) > 0.975)
-      print("Consider making the grid in phi.discrete more dense. The algorithm may have problems moving.")
+      warning("Consider making the grid in phi.discrete more dense. The algorithm may have problems moving.")
   }
-  messages.screen <- ifelse(messages.screen,1,0)
+  messages.C <- ifelse(messages.screen,1,0)
   ##                                                                      
 ##### ---------- sampling ----------- ###### 
   cov.model.number <- cor.number(cov.model)
@@ -50,9 +50,6 @@
   ## remeber this rather odd coding for telling that S.start is from the prior !!!
   if(any(mcmc.input$S.start=="random")) Sdata <- as.double(as.vector(c(rep(0, n.sim*n - 1),1)))
   else Sdata <- as.double(as.vector(c(S, rep(0, (n.sim - 1) * n))))
-  phi.sample <- as.double(rep(phi, n.sim))
-  acc.rate <- rep(0,floor(n.iter/1000)+1)
-  acc.rate.phi <- rep(0,floor(n.iter/1000)+1)
   result <-  .C("mcmcrun4",
                 as.integer(n),
                 as.double(data),
@@ -70,16 +67,16 @@
                 as.integer(n.iter),
                 as.integer(thin),
                 as.integer(burn.in),
-                as.integer(messages.screen),
+                as.integer(messages.C),
                 as.double(ss.sigma),
                 as.integer(df),
                 as.double(phi.prior),
                 as.double(phi.discrete),
                 as.integer(nmphi),
                 Sdata = Sdata,
-                phi.sample = phi.sample,
-		acc.rate = acc.rate, 
-		acc.rate.phi = acc.rate.phi, DUP=FALSE, PACKAGE = "geoRglm")[c("Sdata", "phi.sample","acc.rate","acc.rate.phi" )]
+                phi.sample = as.double(rep(phi, n.sim)),
+		acc.rate = rep(0,floor(n.iter/1000)+1), 
+		acc.rate.phi = rep(0,floor(n.iter/1000)+1), DUP=FALSE, PACKAGE = "geoRglm")[c("Sdata", "phi.sample","acc.rate","acc.rate.phi" )]
   attr(result$Sdata, "dim") <- c(n, n.sim)
   if(nmphi>1) result$acc.rate <- as.data.frame(cbind(burn.in + seq(0,floor(n.iter/1000))*1000, result$acc.rate,result$acc.rate.phi))
   else result$acc.rate <- as.data.frame(cbind(burn.in + seq(0,floor(n.iter/1000))*1000, result$acc.rate))
@@ -87,7 +84,7 @@
   if(burn.in==0) result$acc.rate <- result$acc.rate[-1,]
   if(nmphi>1) names(result$acc.rate) <- c("iter.numb", "Acc.rate", "Acc.rate.phi")
   else names(result$acc.rate) <- c("iter.numb", "Acc.rate")
-  cat(paste("MCMC performed: n.iter. = ", n.iter, "; thinning = ", thin, "; burn.in = ", burn.in, "\n"))
+  if(messages.screen) cat(paste("MCMC performed: n.iter. = ", n.iter, "; thinning = ", thin, "; burn.in = ", burn.in, "\n"))
   return(result)
 }
 
@@ -130,9 +127,9 @@
   else {
     phi.scale <- mcmc.input$phi.scale
     if(nmphi > 1 && pnorm((phi.discrete[nmphi] - phi.discrete[1])/(nmphi - 1), sd = sqrt(phi.scale)) > 0.975)
-      print("Consider making the grid in phi.discrete more dense. The algorithm may have problems moving. ")
+      warning("Consider making the grid in phi.discrete more dense. The algorithm may have problems moving. ")
   }
-  messages.screen <- ifelse(messages.screen,1,0)
+  messages.C <- ifelse(messages.screen,1,0)
   ##                                                                      
 ##### ---------- sampling ----------- ###### 
   cov.model.number <- cor.number(cov.model)
@@ -142,9 +139,6 @@
   ## remeber this rather odd coding for telling that S.start is from the prior !!!
   if(any(mcmc.input$S.start=="random")) Sdata <- as.double(as.vector(c(rep(0, n.sim*n - 1),1)))
   else Sdata <- as.double(as.vector(c(S, rep(0, (n.sim - 1) * n))))
-  phi.sample <- as.double(rep(phi, n.sim))
-  acc.rate <- rep(0,floor(n.iter/1000)+1)
-  acc.rate.phi <- rep(0,floor(n.iter/1000)+1)
   result <-  .C("mcmcrun4boxcox",
                 as.integer(n),
                 as.double(data),
@@ -162,7 +156,7 @@
                 as.integer(n.iter),
                 as.integer(thin),
                 as.integer(burn.in),
-                as.integer(messages.screen),
+                as.integer(messages.C),
                 as.double(ss.sigma),
                 as.integer(df),
                 as.double(phi.prior),
@@ -170,9 +164,9 @@
                 as.integer(nmphi),
                 as.double(lambda),
                 Sdata = Sdata,
-                phi.sample = phi.sample, 
-		acc.rate = acc.rate, 
-		acc.rate.phi = acc.rate.phi, DUP=FALSE, PACKAGE = "geoRglm")[c("Sdata", "phi.sample","acc.rate","acc.rate.phi" )]   
+                phi.sample = as.double(rep(phi, n.sim)), 
+		acc.rate = rep(0,floor(n.iter/1000)+1), 
+		acc.rate.phi = rep(0,floor(n.iter/1000)+1), DUP=FALSE, PACKAGE = "geoRglm")[c("Sdata", "phi.sample","acc.rate","acc.rate.phi" )]   
   attr(result$Sdata, "dim") <- c(n, n.sim)
   if(nmphi>1) result$acc.rate <- as.data.frame(cbind(burn.in + seq(0,floor(n.iter/1000))*1000, result$acc.rate,result$acc.rate.phi))
   else result$acc.rate <- as.data.frame(cbind(burn.in + seq(0,floor(n.iter/1000))*1000, result$acc.rate))
@@ -180,7 +174,7 @@
   if(burn.in==0) result$acc.rate <- result$acc.rate[-1,]
   if(nmphi>1) names(result$acc.rate) <- c("iter.numb", "Acc.rate", "Acc.rate.phi")
   else names(result$acc.rate) <- c("iter.numb", "Acc.rate")
-  cat(paste("MCMC performed: n.iter. = ", n.iter, "; thinning = ", thin, "; burn.in = ", burn.in, "\n"))
+  if(messages.screen) cat(paste("MCMC performed: n.iter. = ", n.iter, "; thinning = ", thin, "; burn.in = ", burn.in, "\n"))
   return(result)
 }
 
@@ -223,9 +217,9 @@
   else {
     phi.scale <- mcmc.input$phi.scale
     if(nmphi > 1 && pnorm((phi.discrete[nmphi] - phi.discrete[1])/(nmphi - 1), sd = sqrt(phi.scale)) > 0.975)
-      print("Consider making the grid in phi.discrete more dense. The algorithm may have problems moving. ")
+      warning("Consider making the grid in phi.discrete more dense. The algorithm may have problems moving. ")
   }
-  messages.screen <- ifelse(messages.screen,1,0)
+  messages.C <- ifelse(messages.screen,1,0)
   ##                                                                      
   ## ---------- sampling ----------- ###### 
   cov.model.number <- cor.number(cov.model)
@@ -234,9 +228,6 @@
   ## remeber this rather odd coding for telling that S.start is from the prior !!!
   if(any(mcmc.input$S.start=="random")) Sdata <- as.double(as.vector(c(rep(0, n.sim*n - 1),1)))
   else Sdata <- as.double(as.vector(c(S, rep(0, (n.sim - 1) * n))))
-  phi.sample <- as.double(rep(phi, n.sim))
-  acc.rate <- rep(0,floor(n.iter/1000)+1)
-  acc.rate.phi <- rep(0,floor(n.iter/1000)+1)
   result <-  .C("mcmcrun5",
                 as.integer(n),
                 as.double(data),
@@ -254,16 +245,16 @@
                 as.integer(n.iter),
                 as.integer(thin),
                 as.integer(burn.in),
-                as.integer(messages.screen),
+                as.integer(messages.C),
                 as.double(ss.sigma),
                 as.integer(df),
                 as.double(phi.prior),
                 as.double(phi.discrete),
                 as.integer(nmphi),
                 Sdata = Sdata,
-                phi.sample = phi.sample,
-		acc.rate = acc.rate, 
-		acc.rate.phi = acc.rate.phi, DUP=FALSE, PACKAGE = "geoRglm")[c("Sdata", "phi.sample","acc.rate","acc.rate.phi" )]
+                phi.sample = as.double(rep(phi, n.sim)),
+		acc.rate = rep(0,floor(n.iter/1000)+1), 
+		acc.rate.phi = rep(0,floor(n.iter/1000)+1), DUP=FALSE, PACKAGE = "geoRglm")[c("Sdata", "phi.sample","acc.rate","acc.rate.phi" )]
   attr(result$Sdata, "dim") <- c(n, n.sim) 
   if(nmphi>1) result$acc.rate <- as.data.frame(cbind(burn.in + seq(0,floor(n.iter/1000))*1000, result$acc.rate,result$acc.rate.phi))
   else result$acc.rate <- as.data.frame(cbind(burn.in + seq(0,floor(n.iter/1000))*1000, result$acc.rate))
@@ -271,7 +262,7 @@
   if(burn.in==0) result$acc.rate <- result$acc.rate[-1,]
   if(nmphi>1) names(result$acc.rate) <- c("iter.numb", "Acc.rate", "Acc.rate.phi")
   else names(result$acc.rate) <- c("iter.numb", "Acc.rate")
-  cat(paste("MCMC performed: n.iter. = ", n.iter, "; thinning = ", thin, "; burn.in = ", burn.in, "\n"))
+  if(messages.screen) cat(paste("MCMC performed: n.iter. = ", n.iter, "; thinning = ", thin, "; burn.in = ", burn.in, "\n"))
   return(result)
 }
 
@@ -314,9 +305,9 @@
   else {
     phi.scale <- mcmc.input$phi.scale
     if(nmphi > 1 && pnorm((phi.discrete[nmphi] - phi.discrete[1])/(nmphi - 1), sd = sqrt(phi.scale)) > 0.975)
-      print("Consider making the grid in phi.discrete more dense. The algorithm may have problems moving. ")
+      warning("Consider making the grid in phi.discrete more dense. The algorithm may have problems moving. ")
   }
-  messages.screen <- ifelse(messages.screen,1,0)
+  messages.C <- ifelse(messages.screen,1,0)
   ##                                         
   ## ---------- sampling ----------- ###### 
   cov.model.number <- cor.number(cov.model)
@@ -325,9 +316,6 @@
   ## remeber this rather odd coding for telling that S.start is from the prior !!!
   if(any(mcmc.input$S.start=="random")) Sdata <- as.double(as.vector(c(rep(0, n.sim*n - 1),1)))
   else Sdata <- as.double(as.vector(c(S, rep(0, (n.sim - 1) * n))))
-  phi.sample <- as.double(rep(phi, n.sim))
-  acc.rate <- rep(0,floor(n.iter/1000)+1)
-  acc.rate.phi <- rep(0,floor(n.iter/1000)+1)
   result <-  .C("mcmcrun5boxcox",
                 as.integer(n),
                 as.double(data),
@@ -345,7 +333,7 @@
                 as.integer(n.iter),
                 as.integer(thin),
                 as.integer(burn.in),
-                as.integer(messages.screen),
+                as.integer(messages.C),
                 as.double(ss.sigma),
                 as.integer(df),
                 as.double(phi.prior),
@@ -353,9 +341,9 @@
                 as.integer(nmphi),
                 as.double(lambda),
                 Sdata = Sdata,
-                phi.sample = phi.sample, 
-		acc.rate = acc.rate, 
-		acc.rate.phi = acc.rate.phi, DUP=FALSE, PACKAGE = "geoRglm")[c("Sdata", "phi.sample","acc.rate","acc.rate.phi" )]
+                phi.sample = as.double(rep(phi, n.sim)), 
+		acc.rate = rep(0,floor(n.iter/1000)+1), 
+		acc.rate.phi = rep(0,floor(n.iter/1000)+1), DUP=FALSE, PACKAGE = "geoRglm")[c("Sdata", "phi.sample","acc.rate","acc.rate.phi" )]
   attr(result$Sdata, "dim") <- c(n, n.sim)
   if(nmphi>1) result$acc.rate <- as.data.frame(cbind(burn.in + seq(0,floor(n.iter/1000))*1000, result$acc.rate,result$acc.rate.phi))
   else result$acc.rate <- as.data.frame(cbind(burn.in + seq(0,floor(n.iter/1000))*1000, result$acc.rate))
@@ -363,7 +351,7 @@
   if(burn.in==0) result$acc.rate <- result$acc.rate[-1,]
   if(nmphi>1) names(result$acc.rate) <- c("iter.numb", "Acc.rate", "Acc.rate.phi")
   else names(result$acc.rate) <- c("iter.numb", "Acc.rate")
-  cat(paste("MCMC performed: n.iter. = ", n.iter, "; thinning = ", thin, "; burn.in = ", burn.in, "\n"))
+  if(messages.screen) cat(paste("MCMC performed: n.iter. = ", n.iter, "; thinning = ", thin, "; burn.in = ", burn.in, "\n"))
   return(result)
 }
 
@@ -622,7 +610,7 @@
 ###########
   if(missing(geodata))
     geodata <- list(coords=coords, data=data, units.m=units.m)
-  if(is.R()) require(mva)
+  require(mva)
   call.fc <- match.call()
   seed <- get(".Random.seed", envir=.GlobalEnv, inherits = FALSE)
   do.prediction <- ifelse(all(locations == "no"), FALSE, TRUE)
@@ -823,7 +811,7 @@
       }
     }
     kb.results$posterior$phi$sample <- gauss.post$phi.sample
-  }   
+  }
   kb.results$posterior$acc.rate  <- gauss.post$acc.rate
   gauss.post <- gauss.post$Sdata
   ##           
@@ -948,7 +936,7 @@
   attr(kb.results, "prediction.locations") <- call.fc$locations
   if(do.prediction) attr(kb.results, 'sp.dim') <- ifelse(krige1d, "1d", "2d")
   if(!is.null(call.fc$borders)) attr(kb.results, "borders") <- call.fc$borders
-  attr(kb.results, "class") <- "glm.krige.bayes"
+  class(kb.results) <- "glm.krige.bayes"
   if(messages.screen) cat("pois.krige.bayes: done!\n")
   return(kb.results)
 }
